@@ -25,12 +25,12 @@ from cascade.data import BruteforceCacher, Wrapper
 
 def test_ds(number_dataset):
     ds = BruteforceCacher(number_dataset)
-    assert([number_dataset[i] for i in range(len(number_dataset))] == [item for item in ds])
+    assert [number_dataset[i] for i in range(len(number_dataset))] == [item for item in ds]
 
 
 def test_it(number_iterator):
     ds = BruteforceCacher(number_iterator)
-    assert([item for item in number_iterator] == [item for item in ds])
+    assert [item for item in number_iterator] == [item for item in ds]
 
 
 def test_meta():
@@ -38,4 +38,4 @@ def test_meta():
     ds = BruteforceCacher(ds)
     meta = ds.get_meta()
 
-    assert(len(meta) == 2)
+    assert len(meta) == 2
