@@ -17,21 +17,45 @@ limitations under the License.
 import os
 import sys
 import pytest
+from numpy import random
+
+SEED = 0
 
 MODULE_PATH = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
 sys.path.append(os.path.dirname(MODULE_PATH))
 
 from cascade.data import RandomSampler, Wrapper
 
+
 @pytest.mark.parametrize(
-    'arr', [
-        ([1, 2, 3, 4, 5],),
-        ([1, 5],),
-        ([1, 2, -3],)
+    'arr, result', [
+        ([1, 2, 3, 4, 5], [3, 1, 2, 4, 5]),
+        ([1, 5], [5, 1]),
+        ([1, 2, -3], [-3, 2, 1])
     ]
 )
-def test(arr):
-   ds = Wrapper(arr)
-   ds = RandomSampler(ds)
+def test(arr, result):
+    random.seed(SEED)
 
-   assert([ds[i] for i in range(len(ds))] != arr)
+    ds = Wrapper(arr)
+    ds = RandomSampler(ds)
+
+    for item, res in zip(ds, result):
+        assert item == res
+
+
+@pytest.mark.parametrize(
+    'arr, result', [
+        ([1, 2, 3, 4, 5], [3, 1, 2]),
+        ([1, 5], [1, 5, 5]),
+        ([1, 2, -3], [-3, 2, 1])
+    ],
+)
+def test_over_and_under(arr, result):
+    random.seed(SEED)
+
+    ds = Wrapper(arr)
+    ds = RandomSampler(ds, 3)
+
+    for item, res in zip(ds, result):
+        assert item == res
