@@ -26,7 +26,7 @@ class FolderImageDataset(FolderDataset):
     """
 
     def __getitem__(self, index):
-        name = self.names[index]
+        name = self._names[index]
         img = cv2.imread(f'{name}')
         if img is not None:
             return cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
